<?php

namespace Modules\Qc\Http\Controllers;


use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\PackingLineQualityRecordHeader;
use Modules\Qc\Entities\PackingLineQualityRecordData;

class PackingLineQualityRecordHeaderController extends Controller
{
    public function allRecords()
    {
        try {
            $query = "SELECT
            qc_packing_line_quality_record_headers.*,
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            pp_customer_orders.purchase_order
        FROM
            qc_packing_line_quality_record_headers
            INNER JOIN
            st_products
            ON
                qc_packing_line_quality_record_headers.product_primary_id = st_products.product_primary_id
            INNER JOIN
            pp_customer_order_plans_data
            ON
                qc_packing_line_quality_record_headers.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
            INNER JOIN
            pp_customer_orders
            ON
                qc_packing_line_quality_record_headers.customer_order_plan_data_id = pp_customer_orders.order_id
        GROUP BY
            qc_packing_line_quality_record_headers.plqr_id";

            $records = DB::select($query);
            $result = array();
            foreach ($records as $record) {
                $packingLineData = PackingLineQualityRecordData::where('plqr_id', $record->plqr_id)->get();
                $total_damage = 0;
                foreach ($packingLineData as $data) {
                    $total_damage += $data->seal_damage1 + $data->seal_damage2 + $data->seal_damage3 + $data->seal_damage4 + $data->seal_damage5 + $data->slab_damage +  $data->print_damage;
                }
                array_push($result, [
                    "plqr_id" => $record->plqr_id,
                    "purchase_order" => $record->purchase_order,
                    "product_name" => $record->product_name,
                    "manufacturing_order_no" => $record->manufacturing_order_no,
                    "trans_date" => $record->trans_date,
                    "total_damage" => $total_damage
                ]);
            }
            $responseBody = $this->responseBody(true, "PackingLineQualityRecordHeaderController", "allRecords", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "PackingLineQualityRecordHeaderController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function getOrderNo()
    {
        try {
            $query = "SELECT
            pp_customer_order_plans_data.customer_order_plan_data_id,
            pp_customer_order_plans.order_id
        FROM
            pp_customer_order_plans_data
            INNER JOIN
            pp_customer_order_plans
            ON
                pp_customer_order_plans_data.customer_order_plan_id = pp_customer_order_plans.customer_order_plan_id
        GROUP BY
            pp_customer_order_plans.order_id";
            $orders = DB::select($query);
            $result = array();
            foreach ($orders as $order) {
                array_push($result, [
                    "customer_order_plan_data_id" => $order->customer_order_plan_data_id,
                    "order_id" => $order->order_id,
                ]);
            }
            $responseBody = $this->responseBody(true, "PackingLineQualityRecordHeaderController", "getOrderNo", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "PackingLineQualityRecordHeaderController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getProductPrimaryId()
    {
        try {
            $query = "SELECT
            pp_machinery_plans.product_primary_id,
            st_products.product_name
        FROM
            pp_machinery_plans
            INNER JOIN
            st_products
            ON
                pp_machinery_plans.product_primary_id = st_products.product_primary_id
        GROUP BY
            pp_machinery_plans.product_primary_id";
            $products = DB::select($query);
            $result = array();
            foreach ($products as $product) {
                array_push($result, [
                    "product_primary_id" => $product->product_primary_id,
                    "product_name" => $product->product_name,
                ]);
            }
            $responseBody = $this->responseBody(true, "PackingLineQualityRecordHeaderController", "getProductPrimaryId", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "PackingLineQualityRecordHeaderController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function deleteRecord($id)
    {
        try {
            if ($this->delete($id)) {
                $rec_data = PackingLineQualityRecordHeader::where('plqr_id', '=', $id)->get();
                foreach ($rec_data as $data) {
                    $data->delete();
                }
                return true;
            }
        } catch (Exception $exception) {
            return false;
        }
    }

    public function delete($id)
    {
        try {
            $rec_data = PackingLineQualityRecordData::where('plqr_id', '=', $id)->get();
            foreach ($rec_data as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }

    public function packingLineReport($id)
    {
        try {
            $query1 = "SELECT
            qc_packing_line_quality_record_headers.*,
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            pp_customer_orders.purchase_order
        FROM
            qc_packing_line_quality_record_headers
            INNER JOIN
            st_products
            ON
                qc_packing_line_quality_record_headers.product_primary_id = st_products.product_primary_id
            INNER JOIN
            pp_customer_order_plans_data
            ON
                qc_packing_line_quality_record_headers.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
            INNER JOIN
            pp_customer_orders
            ON
                qc_packing_line_quality_record_headers.customer_order_plan_data_id = pp_customer_orders.order_id
        WHERE
	        qc_packing_line_quality_record_headers.plqr_id = {$id}";

            $records = DB::select($query1);

            $header = [
                "order_no" => "",
                "product" => "",
                "factory_order_number" => "",
                "trans_date" => "",
            ];


            if ($records) {
                $header["order_no"] = $records[0]->purchase_order;
                $header["product"] = $records[0]->product_name;
                $header["factory_order_number"] = $records[0]->manufacturing_order_no;
                $header["trans_date"] = $records[0]->trans_date;
            }

            $query2 = "SELECT
            qc_packing_line_quality_record_data.*,
            hr_employees.name_withinitial
        FROM
            hr_employees
            INNER JOIN
            qc_packing_line_quality_record_data
            ON
                hr_employees.employee_id = qc_packing_line_quality_record_data.checked_by
                WHERE
                qc_packing_line_quality_record_data.plqr_id = {$id}";

            $data = DB::select($query2);

            $records[0]->request_data = $data;


            $responseBody = $this->responseBody(true, "PackingLineQualityRecordHeaderController", "packingLineReport", ["header" => $header, "body" => ["data" => $data]]);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "PackingLineQualityRecordHeaderController", "packingLineReport", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }




    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
