<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\PallatizingDetailsData;
use Modules\Qc\Entities\PallatizingDetailsHeader;

class PallatizingDetailsHeaderController extends Controller
{
    public function allRecords()
    {
        try {
            $query = "SELECT
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            qc_pallatizing_details_headers.*,
            hr_employee_sites.site
        FROM
            st_products
            INNER JOIN
            pp_customer_order_plans_data
            INNER JOIN
            qc_pallatizing_details_headers
            ON
                pp_customer_order_plans_data.customer_order_plan_data_id = qc_pallatizing_details_headers.customer_order_plan_data_id AND
                st_products.product_primary_id = qc_pallatizing_details_headers.product_primary_id
            INNER JOIN
            hr_employee_sites
            ON
                qc_pallatizing_details_headers.factory = hr_employee_sites.site_id
        GROUP BY
            qc_pallatizing_details_headers.pallatizing_id";

            $records = DB::select($query);
            $result = array();
            foreach ($records as $record) {
                array_push($result, [
                    "pallatizing_id" => $record->pallatizing_id,
                    "reference_no" => $record->reference_no,
                    "product_name" => $record->product_name,
                    "manufacturing_order_no" => $record->manufacturing_order_no,
                    "date" => $record->date,
                    "factory" => $record->site,
                ]);
            }
            $responseBody = $this->responseBody(true, "PallatizingDetailsHeaderController", "allRecords", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "PallatizingDetailsHeaderController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function deleteRecord($id)
    {
        try {
            if ($this->delete($id)) {
                $rec_head = PallatizingDetailsHeader::where('pallatizing_id', '=', $id)->get();
                foreach ($rec_head as $data) {
                    $data->delete();
                }
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }

    public function delete($id) {
        try {
            $rec_data = PallatizingDetailsData::where('pallatizing_id', '=', $id)->get();
                foreach ($rec_data as $data) {
                    $data->delete();
                }
                return true;
        } catch (Exception $exception) {
            return false;
        }
    }


    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
